@@ -100,7 +100,13 @@ def get_puppet_role_path():
 @functools.lru_cache()
 def get_puppet_role_arn(puppet_account_id):
     logger.info("getting puppet_role_arn")
-    return f"arn:{get_partition()}:iam::{puppet_account_id}:role{get_puppet_role_path()}{get_puppet_role_name()}"
+    return get_role_arn(puppet_account_id, get_puppet_role_name())
+
+
+@functools.lru_cache()
+def get_role_arn(puppet_account_id, role_name):
+    logger.info("getting puppet_role_arn")
+    return f"arn:{get_partition()}:iam::{puppet_account_id}:role{get_puppet_role_path()}{role_name}"
 
 
 @functools.lru_cache()
@@ -256,3 +262,7 @@ def get_scheduler_threads_or_processes():
         environmental_variables.SCHEDULER_THREADS_OR_PROCESSES,
         constants.SCHEDULER_THREADS_OR_PROCESSES_DEFAULT,
     )
+
+
+def get_reporting_role_arn(puppet_account_id):
+    return get_role_arn(puppet_account_id, constants.REPORTING_ROLE_NAME)
