@@ -7,6 +7,7 @@ class SharePortfolioViaOrgsTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
     portfolio = "portfolio"
     ou_to_share_with = "ou_to_share_with"
     portfolio_task_reference = "portfolio_task_reference"
+    share_tag_options = True
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.portfolio.sharing_management import (
@@ -21,6 +22,7 @@ class SharePortfolioViaOrgsTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
             portfolio=self.portfolio,
             ou_to_share_with=self.ou_to_share_with,
             portfolio_task_reference=self.portfolio_task_reference,
+            share_tag_options=self.share_tag_options,
         )
 
         self.wire_up_mocks()
@@ -32,6 +34,7 @@ class SharePortfolioViaOrgsTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
             "portfolio": self.portfolio,
             "region": self.region,
             "ou_to_share_with": self.ou_to_share_with,
+            "share_tag_options": self.share_tag_options,
         }
 
         # exercise
